==> 2.1.7.tar.gz: android/src/main/java/com/netmera/netmera_flutter_sdk/FNetmeraPushBroadcastReceiver.java <==
package com.netmera.netmera_flutter_sdk;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;

import com.google.gson.Gson;
import com.netmera.NetmeraCarouselObject;
import com.netmera.NetmeraPushObject;
import com.netmera.callbacks.NMPushActionCallbacks;

import io.flutter.FlutterInjector;

/**
 * Copyright (c) 2019 Inomera Research.
 *
 * @author Burak Soykal
 */
public class FNetmeraPushBroadcastReceiver implements NMPushActionCallbacks {

    private static final String TAG = "Netmera Android";

    public static final String ON_PUSH_REGISTER = "onPushRegister";
    public static final String ON_PUSH_RECEIVE = "onPushReceive";
    public static final String ON_PUSH_OPEN = "onPushOpen";
    public static final String ON_PUSH_DISMISS = "onPushDismiss";
    public static final String ON_PUSH_BUTTON_CLICKED = "onPushButtonClicked";
    public static final String ON_CAROUSEL_OBJECT_SELECTED = "onCarouselObjectSelected";

    @Override
    public void onPushRegister(Context context, String gcmSenderId, String pushToken) {
        Bundle bundle = new Bundle();
        bundle.putString("gcmSenderId", gcmSenderId);
        bundle.putString("pushToken", pushToken);
        sendMessage(context, ON_PUSH_REGISTER, bundle);
    }

    @Override
    public void onPushReceive(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject) {
        sendMessage(context, ON_PUSH_RECEIVE, bundle);
    }

    @Override
    public void onPushOpen(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject) {
        sendMessage(context, ON_PUSH_OPEN, bundle);
    }

    @Override
    public void onPushDismiss(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject) {
        sendMessage(context, ON_PUSH_DISMISS, bundle);
    }

    @Override
    public void onPushButtonClicked(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject) {
        sendMessage(context, ON_PUSH_BUTTON_CLICKED, bundle);
    }

    @Override
    public void onCarouselObjectSelected(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject, int selectedIndex, NetmeraCarouselObject netmeraCarouselObject) {
        bundle.putInt("selectedIndex", selectedIndex);
        bundle.putString("id", netmeraCarouselObject.getId());
        bundle.putString("action", new Gson().toJson(netmeraCarouselObject.getAction()));
        bundle.putString("picturePath", netmeraCarouselObject.getPicturePath());
        sendMessage(context, ON_CAROUSEL_OBJECT_SELECTED, bundle);
    }

    private void sendMessage(Context context, String action, Bundle bundle) {
        FlutterInjector.instance().flutterLoader().ensureInitializationComplete(context, null);
        Intent intent = new Intent(action);
        intent.putExtras(bundle);
        FNetmeraWorker.createAndStart(context, intent);
    }
}

==> 2.1.10.tar.gz: android/src/main/java/com/netmera/netmera_flutter_sdk/FNetmeraPushBroadcastReceiver.java <==
package com.netmera.netmera_flutter_sdk;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;

import com.google.gson.Gson;
import com.netmera.NetmeraCarouselObject;
import com.netmera.NetmeraPushObject;
import com.netmera.callbacks.NMPushActionCallbacks;

import io.flutter.FlutterInjector;

/**
 * Copyright (c) 2019 Inomera Research.
 *
 * @author Burak Soykal
 */
public class FNetmeraPushBroadcastReceiver implements NMPushActionCallbacks {

    private static final String TAG = "Netmera Android";

    public static final String ON_PUSH_REGISTER = "onPushRegister";
    public static final String ON_PUSH_RECEIVE = "onPushReceive";
    public static final String ON_PUSH_OPEN = "onPushOpen";
    public static final String ON_PUSH_DISMISS = "onPushDismiss";
    public static final String ON_PUSH_BUTTON_CLICKED = "onPushButtonClicked";
    public static final String ON_CAROUSEL_OBJECT_SELECTED = "onCarouselObjectSelected";

    @Override
    public void onPushRegister(Context context, String gcmSenderId, String pushToken) {
        Bundle bundle = new Bundle();
        bundle.putString("gcmSenderId", gcmSenderId);
        bundle.putString("pushToken", pushToken);
        sendMessage(context, ON_PUSH_REGISTER, bundle);
    }

    @Override
    public void onPushReceive(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject) {
        sendMessage(context, ON_PUSH_RECEIVE, bundle);
    }

    @Override
    public void onPushOpen(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject) {
        sendMessage(context, ON_PUSH_OPEN, bundle);
    }

    @Override
    public void onPushDismiss(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject) {
        sendMessage(context, ON_PUSH_DISMISS, bundle);
    }

    @Override
    public void onPushButtonClicked(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject) {
        sendMessage(context, ON_PUSH_BUTTON_CLICKED, bundle);
    }

    @Override
    public void onCarouselObjectSelected(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject, int selectedIndex, NetmeraCarouselObject netmeraCarouselObject) {
        bundle.putInt("selectedIndex", selectedIndex);
        bundle.putString("id", netmeraCarouselObject.getId());
        bundle.putString("action", new Gson().toJson(netmeraCarouselObject.getAction()));
        bundle.putString("picturePath", netmeraCarouselObject.getPicturePath());
        sendMessage(context, ON_CAROUSEL_OBJECT_SELECTED, bundle);
    }

    private void sendMessage(final Context context, final String action, final Bundle bundle) {
        new Handler(Looper.getMainLooper()).post(new Runnable() {
            @Override
            public void run() {
                FlutterInjector.instance().flutterLoader().ensureInitializationComplete(context, null);
                Intent intent = new Intent(action);
                intent.putExtras(bundle);
                FNetmeraWorker.createAndStart(context, intent);
            }
        });
    }
}
